@@ -193,7 +193,7 @@
 //! resultcast!(handle.join().unwrap())?;
 //! ```
 
-#![cfg_attr(not(feature = "std"), no_std)]
+#![cfg_attr(all(not(feature = "std"), not(test)), no_std)]
 
 extern crate anyhow;
 /// Master Result
